pre { line-height: 125%; }
td.linenos { user-select: none; padding: 3px;}
td.linenos .normal { color: #ffffff53; background-color: transparent; padding-left: 5px; padding-right: 5px; }
span.linenos { color: #3c4354; background-color: transparent; padding-left: 5px; padding-right: 5px; }
td.linenos .special { color: #3c4354; background-color: #ffffc0; padding-left: 5px; padding-right: 5px; }
span.linenos.special { color: #3c4354; background-color: #ffffc0; padding-left: 5px; padding-right: 5px; }
.hll { background-color: #6e7681 }
.c { color: #7e8aa1 } /* Comment */
.err { color: #f88f7f } /* Error */
.esc { color: #d4d2c8 } /* Escape */
.g { color: #d4d2c8 } /* Generic */
.k { color: #FFAD66 } /* Keyword */
.l { color: #D5FF80 } /* Literal */
.n { color: #d4d2c8 } /* Name */
.o { color: #FFAD66 } /* Operator */
.x { color: #d4d2c8 } /* Other */
.p { color: #d4d2c8 } /* Punctuation */
.ch { color: #f88f7f; font-style: italic } /* Comment.Hashbang */
.cm { color: #7e8aa1 } /* Comment.Multiline */
.cp { color: #FFAD66; font-weight: bold } /* Comment.Preproc */
.cpf { color: #7e8aa1 } /* Comment.PreprocFile */
.c1 { color: #7e8aa1 } /* Comment.Single */
.cs { color: #7e8aa1; font-style: italic } /* Comment.Special */
.gd { color: #f88f7f; background-color: #3d1e20 } /* Generic.Deleted */
.ge { color: #d4d2c8; font-style: italic } /* Generic.Emph */
.ges { color: #d4d2c8 } /* Generic.EmphStrong */
.gr { color: #f88f7f } /* Generic.Error */
.gh { color: #d4d2c8 } /* Generic.Heading */
.gi { color: #6ad4af; background-color: #19362c } /* Generic.Inserted */
.go { color: #7e8aa1 } /* Generic.Output */
.gp { color: #d4d2c8 } /* Generic.Prompt */
.gs { color: #d4d2c8; font-weight: bold } /* Generic.Strong */
.gu { color: #d4d2c8 } /* Generic.Subheading */
.gt { color: #f88f7f } /* Generic.Traceback */
.kc { color: #FFAD66 } /* Keyword.Constant */
.kd { color: #FFAD66 } /* Keyword.Declaration */
.kn { color: #FFAD66 } /* Keyword.Namespace */
.kp { color: #FFAD66 } /* Keyword.Pseudo */
.kr { color: #FFAD66 } /* Keyword.Reserved */
.kt { color: #73D0FF } /* Keyword.Type */
.ld { color: #D5FF80 } /* Literal.Date */
.m { color: #DFBFFF } /* Literal.Number */
.s { color: #D5FF80 } /* Literal.String */
.na { color: #FFD173 } /* Name.Attribute */
.nb { color: #FFD173 } /* Name.Builtin */
.nc { color: #73D0FF } /* Name.Class */
.no { color: #FFD173 } /* Name.Constant */
.nd { color: #7e8aa1; font-weight: bold; font-style: italic } /* Name.Decorator */
.ni { color: #95E6CB } /* Name.Entity */
.ne { color: #73D0FF } /* Name.Exception */
.nf { color: #FFD173 } /* Name.Function */
.nl { color: #d4d2c8 } /* Name.Label */
.nn { color: #d4d2c8 } /* Name.Namespace */
.nx { color: #d4d2c8 } /* Name.Other */
.py { color: #FFD173 } /* Name.Property */
.nt { color: #5CCFE6 } /* Name.Tag */
.nv { color: #d4d2c8 } /* Name.Variable */
.ow { color: #FFAD66 } /* Operator.Word */
.pm { color: #d4d2c8 } /* Punctuation.Marker */
.w { color: #d4d2c8 } /* Text.Whitespace */
.mb { color: #DFBFFF } /* Literal.Number.Bin */
.mf { color: #DFBFFF } /* Literal.Number.Float */
.mh { color: #DFBFFF } /* Literal.Number.Hex */
.mi { color: #DFBFFF } /* Literal.Number.Integer */
.mo { color: #DFBFFF } /* Literal.Number.Oct */
.sa { color: #F29E74 } /* Literal.String.Affix */
.sb { color: #D5FF80 } /* Literal.String.Backtick */
.sc { color: #D5FF80 } /* Literal.String.Char */
.dl { color: #D5FF80 } /* Literal.String.Delimiter */
.sd { color: #7e8aa1 } /* Literal.String.Doc */
.s2 { color: #D5FF80 } /* Literal.String.Double */
.se { color: #95E6CB } /* Literal.String.Escape */
.sh { color: #D5FF80 } /* Literal.String.Heredoc */
.si { color: #95E6CB } /* Literal.String.Interpol */
.sx { color: #95E6CB } /* Literal.String.Other */
.sr { color: #95E6CB } /* Literal.String.Regex */
.s1 { color: #D5FF80 } /* Literal.String.Single */
.ss { color: #DFBFFF } /* Literal.String.Symbol */
.bp { color: #5CCFE6 } /* Name.Builtin.Pseudo */
.fm { color: #FFD173 } /* Name.Function.Magic */
.vc { color: #d4d2c8 } /* Name.Variable.Class */
.vg { color: #d4d2c8 } /* Name.Variable.Global */
.vi { color: #d4d2c8 } /* Name.Variable.Instance */
.vm { color: #d4d2c8 } /* Name.Variable.Magic */
.il { color: #DFBFFF } /* Literal.Number.Integer.Long */